@@ -1,8 +1,9 @@
 package Net::OAI::Base;
 
 use strict;
+use warnings;
 use Carp qw ( croak );
-our $VERSION = 'v1.016.011';
+our $VERSION = "1.16_12";
 
 =head1 NAME
 
