@@ -22,7 +22,7 @@ use Net::OAI::ListSets;
 use Net::OAI::Record::Header;
 use Net::OAI::Record::OAI_DC;
 
-our $VERSION = '1.16_11';
+our $VERSION = "1.16_12";
 our $DEBUG = 0;
 # compatibility mode for metadataHandler
 our $OLDmetadataHandler = 0;
@@ -918,6 +918,10 @@ L<Net::OAI::Record::OAI_DC>
 
 =item *
 
+L<Net::OAI::Record::DocumentHelper>
+
+=item *
+
 L<Net::OAI::Record::NamespaceFilter>
 
 =item *
@@ -939,6 +943,11 @@ Martin Emmerich <Martin.Emmerich@oew.de>
 
 Thomas Berger <ThB@gymel.com>
 
+=head1 LICENSE
+
+This is free software, you may use it and distribute it under the same terms as Perl itself.
+
 =cut
 
 1;
+
