@@ -1,9 +1,10 @@
 package Net::OAI::Record::Header;
 
 use strict;
+use warnings;
 use base qw( XML::SAX::Base );
 use Carp qw( carp );
-our $VERSION = 'v1.016.011';
+our $VERSION = "1.16_12";
 
 
 =head1 NAME
@@ -24,7 +25,7 @@ the C<metadata> child which makes it difficult to access data
 contained in the (possibly multiple) C<about> containers which may follow 
 the C<metadata> in the C<record>.
 
-Beginning from OAI-Harvester v1.17 a new "recordHandler" argument
+Beginning from OAI-Harvester v1.20 a new "recordHandler" argument
 may be given to the harvester functions C<getRecord()> and C<listRecords()>:
 In contrast to a "metadataHandler" argument this will pass the "fwdAll"
 argument to the constructor of this Header class and result in 
@@ -36,7 +37,10 @@ you might set C<$Net::OAI::Harvester::OLDmetadataHandler = 1>,
 in which case the metadataHandler Option behaves like a recordHandler.
 
 The SAX filter implemented by this class purposefully does not generate 
-any start_document() or end_document() events.
+any start_document() or end_document() events. 
+Consider inserting L<Net::OAI::Record::DocumentHelper> as an additional
+filtering stage if your handler(s) need these events, if they fail
+class verification, or if you need a hook for capturing their result.
 
 
 =head1 METHODS
