@@ -1,9 +1,10 @@
 package Net::OAI::Record::OAI_DC;
 
 use strict;
+use warnings;
 use base qw( XML::SAX::Base );
 use Carp qw( carp );
-our $VERSION = 'v1.016.011';
+our $VERSION = "1.16_12";
 
 use constant {
   XMLNS_DC => 'http://purl.org/dc/elements/1.1/',
